@@ -1,9 +1,9 @@
 /*
- * $Id: database.h,v 1.43 2007/08/07 01:06:33 chicoreus Exp $
+ * $Id: database.h,v 1.50 2008/07/30 15:24:55 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,7 +36,7 @@
 
 #define MSG_INCREMENT 200
 #define MAX_CALLSIGN 9       // Objects are up to 9 chars
-#define MAX_TACTICAL_CALL 20 // Up to XX chars for tactical calls
+#define MAX_TACTICAL_CALL 57 // Up to XX chars for tactical calls
 #define MAX_COMMENT_LINES 20  // Save XX unique comment strings per station
 #define MAX_STATUS_LINES 20   // Save XX unique status strings per station
 
@@ -94,6 +94,12 @@ enum APRS_Types {
 #define NORMAL_GPS_RMC  'C'
 #define NORMAL_GPS_GGA  'A'
 #define NORMAL_GPS_GLL  'L'
+#define APRS_WX1        '1'
+#define APRS_WX2        '2'
+#define APRS_WX3        '3'
+#define APRS_WX4        '4'
+#define APRS_WX5        '5'
+#define APRS_WX6        '6'
 
 /* define RECORD ACTIVES */
 #define RECORD_ACTIVE    'A'
@@ -105,6 +111,7 @@ enum APRS_Types {
 #define DATA_VIA_TNC   'T'
 #define DATA_VIA_NET   'I'
 #define DATA_VIA_FILE  'F'
+#define DATA_VIA_DATABASE  'D'
 
 
 /* define Heard info type */
@@ -133,6 +140,9 @@ enum APRS_Types {
 #define MAX_MESSAGE_LENGTH  100
 #define MAX_MESSAGE_ORDER    10
 
+// track export file formats
+#define EXPORT_XASTIR_TRACK 0
+#define EXPORT_KML_TRACK 1
 
 extern char *get_most_recent_ack(char *callsign);
  
@@ -525,6 +535,7 @@ extern void copy_data(DataRow *to, DataRow *from);
 
 
 extern void db_init(void);
+extern void export_trail_as_kml(DataRow *p_station);   // export trail of one or all stations to kml file
 
 //
 extern int is_my_call(char *call, int exact);
@@ -642,4 +653,11 @@ int comp_by_dist(const void *,const void *);// used only for qsort
 DataRow * sanity_check_time_list(time_t); // used only for debugging
 void dump_time_sorted_list(void);
 
+extern int store_trail_point(DataRow *p_station, long lon, long lat, time_t sec, char *alt, char *speed, char *course, short stn_flag);
+
+#ifdef HAVE_DB
+extern int add_simple_station(DataRow *p_new_station,char *station, char *origin, char *symbol, char *overlay, char *aprs_type, char *latitude, char *longitude, char *record_type, char *node_path, char *transmit_time, char *timeformat);
+
+#endif /* HAVE_DB */
+
 #endif /* XASTIR_DATABASE_H */
