@@ -1,9 +1,9 @@
 /*
- * $Id: interface.h,v 1.39 2007/08/07 01:06:33 chicoreus Exp $
+ * $Id: interface.h,v 1.41 2008/01/16 19:34:00 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -207,7 +207,7 @@ typedef struct {
     // device_host_name = hostname for database server 
     // sp = port on which to connect to database server 
     // device_host_pswd =  password to use to connect to database -- security issue needs to be addressed
-#endif /* HAVE_DB */
+#endif  // HAVE_DB
 } ioparam;
 
 
