@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_WMS.c,v 1.28 2007/08/17 22:08:10 gstueve Exp $
+ * $Id: map_WMS.c,v 1.34 2008/08/01 12:42:59 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -89,6 +89,15 @@
 # endif // HAVE_SYS_TIME_H
 #endif  // TIME_WITH_SYS_TIME
 #undef RETSIGTYPE
+// TVR: "stupid ImageMagick"
+// The problem is that magick/api.h includes Magick's config.h file, and that
+// pulls in all the same autoconf-generated defines that we use.
+// plays those games below, but I don't think in the end that they actually 
+// make usable macros with our own data in them.
+// Fortunately, we don't need them, so I'll just undef the ones that are
+// causing problems today.  See main.c for fixes that preserve our values.
+#undef PACKAGE
+#undef VERSION
 /* JMT - stupid ImageMagick */
 #define XASTIR_PACKAGE_BUGREPORT PACKAGE_BUGREPORT
 #undef PACKAGE_BUGREPORT
@@ -128,13 +137,6 @@
 
 
 
-extern int npoints;		/* tsk tsk tsk -- globals */
-extern int mag;
-
-
-
-
-
 /**********************************************************
  * draw_WMS_map()
  **********************************************************/
@@ -585,8 +587,10 @@ void draw_WMS_map (Widget w,
 #endif // USE_MAP_CACHE
 
 
-    (debug_level & 512) && fprintf (stderr, "Fetch or query took %d seconds\n", 
-                            (int) (time(&query_end_time) - query_start_time)); 
+    if (debug_level & 512) {
+        fprintf (stderr, "Fetch or query took %d seconds\n", 
+            (int) (time(&query_end_time) - query_start_time)); 
+    }
 
     // Set permissions on the file so that any user can overwrite it.
     chmod(local_filename, 0666);
@@ -629,6 +633,9 @@ void draw_WMS_map (Widget w,
         }
 #endif
          
+        if (image_info)
+            DestroyImageInfo(image_info);
+	DestroyExceptionInfo(&exception);
         return;
     }
     (void)fclose (f);
@@ -649,6 +656,9 @@ void draw_WMS_map (Widget w,
         }
 #endif
 
+        if (image_info)
+            DestroyImageInfo(image_info);
+	DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -662,6 +672,7 @@ void draw_WMS_map (Widget w,
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -714,6 +725,7 @@ void draw_WMS_map (Widget w,
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -725,6 +737,7 @@ void draw_WMS_map (Widget w,
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -925,7 +938,6 @@ void draw_WMS_map (Widget w,
 
         HandlePendingEvents(app_context);
         if (interrupt_drawing_now) {
-            (void)fclose (f);
             if (image)
                 DestroyImage(image);
             if (image_info)
@@ -1006,5 +1018,6 @@ void draw_WMS_map (Widget w,
        DestroyImage(image);
     if (image_info)
        DestroyImageInfo(image_info);
+    DestroyExceptionInfo(&exception);
 }
 #endif //HAVE_MAGICK
