@@ -1,9 +1,9 @@
 /*
- * $Id: map_cache.c,v 1.29 2007/08/17 22:08:10 gstueve Exp $
+ * $Id: map_cache.c,v 1.31 2008/01/23 06:00:37 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -243,9 +243,12 @@ int map_cache_put( char * map_cache_url, char * map_cache_file ){
 
 // mc_ret is assigned here but not used.  Commented it out for now.
     if (((/* mc_ret = */ dbp->get(dbp, NULL, &mc_key, &mc_data, 0)) == 0) &&  ( mc_data.data != NULL ) ) {
-        ( debug_level & 512 ) && fprintf(stderr, "map_cache_put: %s: key retrieved: data was %s.\n",
-            (mc_key.data == NULL) ? "(null)" : (char *)mc_key.data,
-            (mc_data.data == NULL) ? "(null)" : (char *)mc_data.data);
+
+        if ( debug_level & 512 ) {
+            fprintf(stderr, "map_cache_put: %s: key retrieved: data was %s.\n",
+                (mc_key.data == NULL) ? "(null)" : (char *)mc_key.data,
+                (mc_data.data == NULL) ? "(null)" : (char *)mc_data.data);
+        }
 
         if (mc_data.data == NULL)
             mc_space_used = 0;
