@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_geo.c,v 1.88 2007/08/31 12:20:53 gstueve Exp $
+ * $Id: map_geo.c,v 1.94 2008/08/06 03:03:54 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -102,6 +102,15 @@
 # endif // HAVE_SYS_TIME_H
 #endif  // TIME_WITH_SYS_TIME
 #undef RETSIGTYPE
+// TVR: "stupid ImageMagick"
+// The problem is that magick/api.h includes Magick's config.h file, and that
+// pulls in all the same autoconf-generated defines that we use.
+// plays those games below, but I don't think in the end that they actually 
+// make usable macros with our own data in them.
+// Fortunately, we don't need them, so I'll just undef the ones that are
+// causing problems today.  See main.c for fixes that preserve our values.
+#undef PACKAGE
+#undef VERSION
 /* JMT - stupid ImageMagick */
 #define XASTIR_PACKAGE_BUGREPORT PACKAGE_BUGREPORT
 #undef PACKAGE_BUGREPORT
@@ -1309,7 +1318,10 @@ fprintf(stderr,"1 ");
 	        }
             }
 #endif
-                return;
+               if (image_info)
+                 DestroyImageInfo(image_info);
+               DestroyExceptionInfo(&exception);
+               return;
             }
             (void)fclose (f);
             
@@ -1328,6 +1340,9 @@ fprintf(stderr,"1 ");
             }
 #endif
 
+               if (image_info)
+                 DestroyImageInfo(image_info);
+               DestroyExceptionInfo(&exception);
                 return;
             }
             
@@ -1592,8 +1607,10 @@ fprintf(stderr,"1 ");
         } // end if is cached
 #endif // MAP_CACHE
 
-        (debug_level & 512) && fprintf (stderr, "Fetch or query took %d seconds\n", 
-                            (int) (time(&query_end_time) - query_start_time)); 
+        if (debug_level & 512) {
+            fprintf (stderr, "Fetch or query took %d seconds\n", 
+                (int) (time(&query_end_time) - query_start_time)); 
+        }
 
         // Set permissions on the file so that any user can overwrite it.
         chmod(local_filename, 0666);
@@ -1653,6 +1670,9 @@ fprintf(stderr,"1 ");
     if (f == NULL) {
 fprintf(stderr,"2 ");
         fprintf(stderr,"File %s could not be read\n",image_info->filename);
+        if (image_info)
+          DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
     (void)fclose (f);
@@ -1670,6 +1690,9 @@ fprintf(stderr,"2 ");
             (unsigned int)screen_height,
             0,
             0);
+        if (image_info)
+          DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -1678,6 +1701,9 @@ fprintf(stderr,"2 ");
     if (image == (Image *) NULL) {
         MagickWarning(exception.severity, exception.reason, exception.description);
         //fprintf(stderr,"MagickWarning\n");
+        if (image_info)
+          DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -1886,7 +1912,7 @@ fprintf(stderr,"2 ");
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
-       DestroyExceptionInfo(&exception);
+        DestroyExceptionInfo(&exception);
          return;
     }
 
@@ -1901,6 +1927,7 @@ fprintf(stderr,"2 ");
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -1910,7 +1937,7 @@ fprintf(stderr,"2 ");
 
     if (debug_level & 16)
 #ifdef HAVE_GRAPHICSMAGICK
-        fprintf(stderr,"Colors = %d\n", image->colors);
+        fprintf(stderr,"Colors = %d\n", (int)image->colors);
 #else   // HAVE_GRAPHICSMAGICK
         fprintf(stderr,"Colors = %ld\n", image->colors);
 #endif  // HAVE_GRAPHICSMAGICK
