@@ -1,9 +1,9 @@
 /*
- * $Id: messages.c,v 1.71 2007/08/24 13:42:46 gstueve Exp $
+ * $Id: messages.c,v 1.74 2008/05/27 19:04:18 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -228,8 +228,12 @@ int group_active(char *from) {
     if ((!stat( get_user_base_dir(group_data_file), &group_stat )
             && (current_group_stat.st_size != group_stat.st_size
                 || current_group_stat.st_mtime != group_stat.st_mtime
-                || current_group_stat.st_ctime != group_stat.st_ctime))
-                || (altgroup && strcasecmp(altgroup, VERSIONFRM))) {
+                || current_group_stat.st_ctime != group_stat.st_ctime))) {
+
+// altgroup equates to "address of altgroup" which always evaluates
+// as true.  Commenting it out of the conditional.  --we7u.
+//                || (altgroup && strcasecmp(altgroup, VERSIONFRM))) {
+
         group_build_list( get_user_base_dir(group_data_file) );
         current_group_stat = group_stat;
         xastir_snprintf(altgroup,sizeof(altgroup),"%s",VERSIONFRM);
@@ -573,8 +577,9 @@ end_critical_section(&send_message_dialog_lock, "messages.c:clear_outgoing_messa
 // sending the sequence number in Base-?? format in order to get
 // more range from the 2-character variable.
 //
-void bump_message_counter(void) {
+int bump_message_counter(char *message_counter) {
 
+    int bump_warning = 0;
     message_counter[2] = '\0';  // Terminate at 2 chars
 
     // Increment the least significant digit
@@ -601,8 +606,9 @@ void bump_message_counter(void) {
 
     if (message_counter[0] == '{') {
         message_counter[0] = '0';
-        message_counter[0]++;
+        bump_warning = 1;
     }
+    return bump_warning;
 }
 
 
@@ -704,7 +710,8 @@ void output_message(char *from, char *to, char *message, char *path) {
                 ok=1;
 
                 // Increment the message sequence ID variable
-                bump_message_counter();
+                if (bump_message_counter(message_counter)) 
+		   fprintf(stderr, "!WARNING!: Wrap around Message Counter");
 
 
 // Note that Xastir's messaging can lock up if we do a rollover and
