@@ -1,9 +1,9 @@
 /*
- * $Id: track_gui.c,v 1.66 2007/09/25 02:41:31 we7u Exp $
+ * $Id: track_gui.c,v 1.71 2008/07/02 03:04:44 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,6 +47,7 @@
 #include "leak_detection.h"
 
 
+extern XmFontList fontlist1;    // Menu/System fontlist
 
 Widget track_station_dialog = (Widget)NULL;
 Widget track_station_data = (Widget)NULL;
@@ -208,6 +209,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 xmDialogShellWidgetClass, appshell,
                 XmNdeleteResponse, XmDESTROY,
                 XmNdefaultPosition, FALSE,
+                XmNfontList, fontlist1,
                 NULL);
 
         pane = XtVaCreateWidget("Track_station pane",
@@ -238,6 +240,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNrightAttachment, XmATTACH_NONE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         track_station_data = XtVaCreateManagedWidget("Track_station track locate data", 
@@ -260,6 +263,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNrightAttachment,XmATTACH_NONE,
                 XmNnavigationType, XmTAB_GROUP,
                 XmNtraversalOn, TRUE,
+                XmNfontList, fontlist1,
                 NULL);
 
         track_case_data  = XtVaCreateManagedWidget(langcode("WPUPTSP003"),
@@ -276,6 +280,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         track_match_data  = XtVaCreateManagedWidget(langcode("WPUPTSP004"),
@@ -293,6 +298,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         sep = XtVaCreateManagedWidget("Track_station sep", 
@@ -307,6 +313,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNrightAttachment,XmATTACH_FORM,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         button_ok = XtVaCreateManagedWidget(langcode("WPUPTSP005"),
@@ -326,6 +333,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         button_clear = XtVaCreateManagedWidget(langcode("WPUPTSP006"),
@@ -344,6 +352,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         button_close = XtVaCreateManagedWidget(langcode("UNIOP00003"),
@@ -363,6 +372,7 @@ begin_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" )
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         XtAddCallback(button_ok, XmNactivateCallback, Track_station_now, track_station_dialog);
@@ -406,6 +416,15 @@ end_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" );
 /***** DOWNLOAD FINDU TRAILS *****/
 
 
+
+// Struct used for passing two parameters to findu_transfer_thread
+typedef struct {
+    char *download_client_ptrs[2];
+} track_ptrs_struct;
+track_ptrs_struct track_ptrs;
+
+
+
 // This is the separate execution thread that fetches the track from
 // findu.  The thread is started up by the Download_trail_now()
 // function below.
@@ -471,58 +490,67 @@ static void* findu_transfer_thread(void *arg) {
     //
 // "sed -i -e \"s/<br>/   <br>/\" %s",
     sprintf(sys_cmd,
-        "sed -i -e \"s/<br>/   /\" %s",
+        "%s -i -e \"s/<br>/   /\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 //fprintf(stderr,"%s\n", sys_cmd);
 
 // Greater-than symbol '>'
     sprintf(sys_cmd,
-        "sed -i -e \"s/&gt;/>/\" %s",
+        "%s -i -e \"s/&gt;/>/\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Less-than symbol '<'
     sprintf(sys_cmd,
-        "sed -i -e \"s/&lt;/</\" %s",
+        "%s -i -e \"s/&lt;/</\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Ampersand '&' (A difficult character to escape from the shell!)
     sprintf(sys_cmd,
-        "sed -i -e \"s/&amp;/\\&/\" %s",
+        "%s -i -e \"s/&amp;/\\&/\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Double-quote symbol '"'
     sprintf(sys_cmd,
-        "sed -i -e \"s/&quot;/""/\" %s",
+        "%s -i -e \"s/&quot;/""/\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Remove whitespace at the start of a line
 // sed 's/^[ \t]*//'
     sprintf(sys_cmd,
-        "sed -i -e \"s/^[ \t]*//\" %s",
+        "%s -i -e \"s/^[ \t]*//\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Remove any lines that start with '<'
     sprintf(sys_cmd,
-        "sed -i -e \"s/^<.*$//\" %s",
+        "%s -i -e \"s/^<.*$//\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Remove any lines that start with '"http'
     sprintf(sys_cmd,
-        "sed -i -e \"/^\\\"http.*$/d\" %s",
+        "%s -i -e \"/^\\\"http.*$/d\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
 // Remove any blank lines from the file
 // sed '/^$/d'
     sprintf(sys_cmd,
-        "sed -i -e \"/^$/d\" %s",
+        "%s -i -e \"/^$/d\" %s",
+        SED_PATH,
         log_filename);
     system(sys_cmd);
 
@@ -545,7 +573,8 @@ static void* findu_transfer_thread(void *arg) {
     // pointing to it, needed for the read_file_ptr code in the main
     // thread.
     sprintf(sys_cmd,
-        "mv %s %s",
+        "%s %s %s",
+        MV_PATH,
         log_filename_tmp,
         log_filename);
     system(sys_cmd);
@@ -599,7 +628,6 @@ void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
     char *temp_ptr;
     pthread_t download_trail_thread;
     static XtPointer download_client_data = NULL;
-    static char *download_client_ptrs[2];
 
 
     // If we're already fetching a trail, we shouldn't be calling
@@ -607,9 +635,10 @@ void Download_trail_now(Widget w, XtPointer clientData, XtPointer callData) {
     if (fetching_findu_trail_now)
         return;
 
-    download_client_ptrs[0] = log_filename;
-    download_client_ptrs[1] = fileimg;
-    download_client_data = (XtPointer *)download_client_ptrs;
+    // Pass two parameters to findu_transfer_thread via a struct
+    track_ptrs.download_client_ptrs[0] = log_filename;
+    track_ptrs.download_client_ptrs[1] = fileimg;
+    download_client_data = &track_ptrs;
 
     // Check whether it's ok to do a download currently.
     if (read_file) {
@@ -756,6 +785,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 xmDialogShellWidgetClass, appshell,
                 XmNdeleteResponse,XmDESTROY,
                 XmNdefaultPosition, FALSE,
+                XmNfontList, fontlist1,
                 NULL);
 
         pane = XtVaCreateWidget("Download_findu_trail pane",
@@ -786,6 +816,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNrightAttachment, XmATTACH_NONE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         download_trail_station_data = XtVaCreateManagedWidget("download_trail_station_data", 
@@ -808,6 +839,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNrightAttachment,XmATTACH_NONE,
                 XmNnavigationType, XmTAB_GROUP,
                 XmNtraversalOn, TRUE,
+                XmNfontList, fontlist1,
                 NULL);
 
         x_str = XmStringCreateLocalized(langcode("WPUPTSP009"));
@@ -840,6 +872,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNtitleString, x_str,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
         XmStringFree(x_str);
 
@@ -873,6 +906,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNtitleString, x_str,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
         XmStringFree(x_str);
 
@@ -888,6 +922,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNrightAttachment,XmATTACH_FORM,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         button_ok = XtVaCreateManagedWidget(langcode("WPUPTSP007"),
@@ -907,6 +942,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
         if (fetching_findu_trail_now)
             XtSetSensitive(button_ok, FALSE);
@@ -928,6 +964,7 @@ begin_critical_section(&download_findu_dialog_lock, "track_gui.c:Download_findu_
                 XmNtraversalOn, TRUE,
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
+                XmNfontList, fontlist1,
                 NULL);
 
         XtAddCallback(button_ok, XmNactivateCallback, Download_trail_now, download_findu_dialog);
