@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xa_config.c,v 1.170 2007/08/07 01:06:34 chicoreus Exp $
+ * $Id: xa_config.c,v 1.176 2008/08/01 00:09:18 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -579,10 +579,15 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_string (fout, "MAPS_LABEL_FONT_TINY", rotated_label_fontname[FONT_TINY]);
         store_string (fout, "MAPS_LABEL_FONT_SMALL", rotated_label_fontname[FONT_SMALL]);
         store_string (fout, "MAPS_LABEL_FONT_MEDIUM", rotated_label_fontname[FONT_MEDIUM]);
+        // NOTE:  FONT_DEFAULT points to FONT_MEDIUM.
         store_string (fout, "MAPS_LABEL_FONT_LARGE", rotated_label_fontname[FONT_LARGE]);
         store_string (fout, "MAPS_LABEL_FONT_HUGE", rotated_label_fontname[FONT_HUGE]);
         store_string (fout, "MAPS_LABEL_FONT_BORDER", rotated_label_fontname[FONT_BORDER]);
-        store_string (fout, "MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT]);
+        store_string (fout, "SYSTEM_FIXED_FONT", rotated_label_fontname[FONT_SYSTEM]);
+        store_string (fout, "STATION_FONT", rotated_label_fontname[FONT_STATION]);
+        store_string (fout, "ATV_ID_FONT", rotated_label_fontname[FONT_ATV_ID]);
+
+
 //N0VH
 #if defined(HAVE_MAGICK)
         store_int (fout, "NET_MAP_TIMEOUT", net_map_timeout);
@@ -945,6 +950,9 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         // SNAPSHOTS
         store_int (fout, "SNAPSHOTS_ENABLED", snapshots_enabled);
 
+        // KML SNAPSHOTS
+        store_int (fout, "KMLSNAPSHOTS_ENABLED", kmlsnapshots_enabled);
+
         /* WX ALERTS */
         store_long (fout, "WX_ALERTS_REFRESH_TIME", (long)WX_ALERTS_REFRESH_TIME);
 
@@ -1428,6 +1436,7 @@ void load_data_or_default(void) {
             sizeof(rotated_label_fontname[FONT_MEDIUM]),
             "-adobe-helvetica-medium-r-normal--12-*-*-*-*-*-iso8859-1");
     }
+    // NOTE:  FONT_DEFAULT points to FONT_MEDIUM
 
     if (!get_string ("MAPS_LABEL_FONT_LARGE", rotated_label_fontname[FONT_LARGE], sizeof(rotated_label_fontname[FONT_LARGE]))
             || rotated_label_fontname[FONT_LARGE][0] == '\0') {
@@ -1450,13 +1459,34 @@ void load_data_or_default(void) {
             "-adobe-helvetica-medium-r-normal--14-*-*-*-*-*-iso8859-1");
     }
 
-    if (!get_string ("MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT], sizeof(rotated_label_fontname[FONT_DEFAULT]))
-            || rotated_label_fontname[FONT_DEFAULT][0] == '\0') {
-        xastir_snprintf(rotated_label_fontname[FONT_DEFAULT],
-            sizeof(rotated_label_fontname[FONT_DEFAULT]),
-            "-adobe-helvetica-bold-r-normal--12-*-*-*-*-*-iso8859-1");
+    if (!get_string ("SYSTEM_FIXED_FONT", rotated_label_fontname[FONT_SYSTEM], sizeof(rotated_label_fontname[FONT_SYSTEM]))
+            || rotated_label_fontname[FONT_SYSTEM][0] == '\0') {
+        xastir_snprintf(rotated_label_fontname[FONT_SYSTEM],
+            sizeof(rotated_label_fontname[FONT_SYSTEM]),
+            "fixed");
+            // NOTE:  This same default font is hard-coded into
+            // main.c, to be used for the case when the user enters
+            // an invalid font (so the program won't crash).
     }
 
+    if (!get_string ("STATION_FONT", rotated_label_fontname[FONT_STATION], sizeof(rotated_label_fontname[FONT_STATION]))
+            || rotated_label_fontname[FONT_STATION][0] == '\0') {
+        xastir_snprintf(rotated_label_fontname[FONT_STATION],
+            sizeof(rotated_label_fontname[FONT_STATION]),
+            "fixed");
+            // NOTE:  This same default font is hard-coded into
+            // main.c, to be used for the case when the user enters
+            // an invalid font (so the program won't crash).
+    }
+
+    if (!get_string ("ATV_ID_FONT", rotated_label_fontname[FONT_ATV_ID], sizeof(rotated_label_fontname[FONT_ATV_ID]))
+            || rotated_label_fontname[FONT_ATV_ID][0] == '\0') {
+        xastir_snprintf(rotated_label_fontname[FONT_ATV_ID],
+            sizeof(rotated_label_fontname[FONT_ATV_ID]),
+            "-*-helvetica-*-*-*-*-*-240-*-*-*-*-*-*");
+    }
+
+
 //N0VH
 #if defined(HAVE_MAGICK)
     net_map_timeout = get_int ("NET_MAP_TIMEOUT", 10, 300, 120);
@@ -1584,7 +1614,8 @@ void load_data_or_default(void) {
             "%s",
             name_temp);
         strncat (name, "DATABASE_TYPE", sizeof(name) - strlen(name));
-        devices[i].database_type = get_int (name, 0,MAX_DB_TYPE,DB_MYSQL);
+        
+        devices[i].database_type = get_int (name, 0,MAX_DB_TYPE,MAX_DB_TYPE);
         
         xastir_snprintf(name,
             sizeof(name),
@@ -1959,6 +1990,9 @@ void load_data_or_default(void) {
     // SNAPSHOTS
     snapshots_enabled = get_int ("SNAPSHOTS_ENABLED", 0,1,0);
 
+    // KML SNAPSHOTS
+    kmlsnapshots_enabled = get_int ("KMLSNAPSHOTS_ENABLED", 0,1,0);
+
     /* WX ALERTS */
     WX_ALERTS_REFRESH_TIME = (time_t) get_long ("WX_ALERTS_REFRESH_TIME", 10l, 86400l, 60l);
 
