@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xastir.h,v 1.56 2007/08/15 17:41:52 gstueve Exp $
+ * $Id: xastir.h,v 1.60 2008/07/02 03:04:44 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2007  The Xastir Group
+ * Copyright (C) 2000-2008  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -86,7 +86,6 @@ extern Pixmap  pixmap_25pct_stipple;
 extern Pixmap  pixmap_13pct_stipple;
 extern Pixmap  pixmap_wx_stipple;
 
-
 extern Widget appshell;
 
 
@@ -153,14 +152,18 @@ extern int redraw_on_new_data;
 extern int tiger_flag;
 extern int index_maps_on_startup;
 #define MAX_LABEL_FONTNAME 256
-#define FONT_TINY 0
-#define FONT_SMALL 1
-#define FONT_MEDIUM 2
-#define FONT_LARGE 3
-#define FONT_HUGE 4
-#define FONT_BORDER 5
-#define FONT_MAX 6
+#define FONT_SYSTEM  0
+#define FONT_STATION 1
+#define FONT_TINY    2
+#define FONT_SMALL   3
+#define FONT_MEDIUM  4
+#define FONT_LARGE   5
+#define FONT_HUGE    6
+#define FONT_BORDER  7
+#define FONT_ATV_ID  8
+#define FONT_MAX     9
 #define FONT_DEFAULT FONT_MEDIUM
+#define MAX_FONTNAME 256
 extern char rotated_label_fontname[FONT_MAX][MAX_LABEL_FONTNAME];
 
 #ifdef HAVE_MAGICK  //N0VH
